\name{orchONA}
\alias{orchONA}
\title{
  ONA seed orchard layout.
}
\description{
  Function to calculate the ONA seed orchard layout.
}
\usage{
orchONA(ID, GR, niter = 100, weight = 1000,...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ID}{Clonal identification (column 1: clonal ID, column2: respective clonal size, i.e. number of ramets). This input must be declared. User may optionaly declare the actual clonal ID codes as row names of the ID. The function would then return MI layout with these codes.}
  \item{GR}{Seed orchard grid - ascending numbering of planting positions (row-wise from left/up to write/down); zeros: empty positions. This input must be declared.}
  \item{niter}{Number of iterations of the heuristics. When absent, niter = 100.}
  \item{weight}{Penalty in the criterion function (see scientific paper for details). When absent, the default value is 1000.}
  \item{...}{Optional arguments.}
}
\details{
  This function utilizes the following packages: GDATA
}
\value{
Returns a list of two matrices: the optimized ONA layout (matrix with clonal ID's corresponding to the supplied grid matrix) and the PAIR (matrix with counts direct neighboring positions).
}
\references{
Chaloupkova K, Stejskal J, El-Kassaby YA, Lstiburek M (2016). Optimum neighborhood seed orchard design. Tree Genetics & Genomes 12: 105.
}
\author{
Milan Lstiburek
 \email{lstiburek@fld.czu.cz}
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{

%}
\examples{
GRMAT <- matrix(1:9, nrow=3, byrow=TRUE) #grid of 9 positions
#1 2 3
#4 5 6
#7 8 9

#4 clones: 2 ramets,1 clone: 1 ramet
IDMAT <- matrix(0:0, nrow=5, ncol=2)
IDMAT[,1] <- 1:5 #clonal ID's in the first column
IDMAT[,2] <- 2 #clonal sizes in the second column
IDMAT[5,2] <- 1 #clonal sizes in the second column
#1 2
#2 2
#3 2
#4 2
#5 1

layout <- orchONA(ID = IDMAT, GR = GRMAT, niter = 5)
layout$ONA #ONA solution with respective clonal ID at each position
layout$PAIR #matrix PAIRS

#Alternatively, we can assume empty position(s) on the grid:
#GRMAT <- matrix(0:0, nrow=3, ncol=3) #grid of 9 positions
#GRMAT[1,1] <- 1 #note asscending numbering
#GRMAT[1,2] <- 2
#GRMAT[1,3] <- 3
#GRMAT[2,1] <- 4
#GRMAT[2,2] <- 0 #empty position
#GRMAT[2,3] <- 5 #starts where we left
#GRMAT[3,1] <- 6
#GRMAT[3,2] <- 7
#GRMAT[3,3] <- 8
#1 2 3
#4 0 5
#6 7 8

#IDMAT <- matrix(0:0, nrow=4, ncol=2) #4 clones, 2 ramets each
#IDMAT[,1] <- 1:4
#IDMAT[,2] <- 2
#1 2
#2 2
#3 2
#4 2

#Specification of the actual clonal codes:
#rownames(IDMAT) <- c("a", "b", "c", "d")

layout <- orchONA(ID = IDMAT, GR = GRMAT, niter = 5)
layout$ONA
#ONA solution with respective clonal ID at each position:
#c d a
#b 0 b #central position is empty as requested
#a d c

#Bigger input matrices can be prepared externally (e.g., MS Excel):
#list.files()
#IDMAT <- as.matrix(read.delim("ID.dat", header = F))
#GRMAT <- as.matrix(read.delim("grid.dat", header = F))
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~spatial optimization }% use one of  RShowDoc("KEYWORDS")
\keyword{ ~seed orchards }% __ONLY ONE__ keyword per line
\keyword{ ~spatial layout }% __ONLY ONE__ keyword per line
